/*
 * Name:    mp.h
 *
 * Purpose: Python module interface to the MX library.
 *
 * Author:  William Lavender
 *
 *---------------------------------------------------------------------------
 *
 * Copyright 2002-2004 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#ifndef __MP_H__
#define __MP_H__

/* Module initialization function. */

MX_API void initMpPrivate( void );

/* Global variable. */

extern MX_HANDLE_TABLE *MpPrivate_global_record_handle_table;

/* Module functions. */

MX_API mx_status_type MpPrivate_get_record_from_handle( long handle,
							MX_RECORD **record );

MX_API mx_status_type MpPrivate_get_record_from_object( PyObject *object,
							MX_RECORD **record );

MX_API mx_status_type MpPrivate_create_field_from_tuple( MX_RECORD *record,
							MX_RECORD_FIELD *field,
							PyObject *tuple );

MX_API mx_status_type MpPrivate_create_tuple_from_field( MX_RECORD *record,
							MX_RECORD_FIELD *field,
							PyObject **new_tuple );

MX_API      void MpPrivateErr_SetString( PyObject *exception_object,
					char *format, ... );

MX_API PyObject *MpPrivateErr_SetFromMxStatus( PyObject *error_object,
					mx_status_type mx_status );

MX_API PyObject *MpPrivate_init_cmd( PyObject *self, PyObject *args );

/*===*/

MX_API PyObject *MpPrivate_info_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_set_info_output_function_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_warning_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_set_warning_output_function_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_set_error_output_function_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_debug_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_set_debug_output_function_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_get_debug_level_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_set_debug_level_cmd( PyObject *self,
							PyObject *args );

/*===*/

MX_API PyObject *MpPrivate_info_dialog_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_set_info_dialog_function_cmd( PyObject *self,
							PyObject *args );
/*===*/

MX_API PyObject *MpPrivate_user_requested_interrupt_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_set_user_interrupt_function_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_getch_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_kbhit_cmd( PyObject *self, PyObject *args );

/*===*/

MX_API PyObject *MpPrivate_plotting_is_enabled_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_set_plot_enable_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_set_program_name_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_install_user_interrupt_handler_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_install_output_handlers_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_install_dialog_handler_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_create_record_list_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_read_database_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_finish_database_initialization_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_initialize_hardware_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_shutdown_hardware_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_create_record_from_description_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_finish_record_initialization_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_delete_record_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_get_record_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_get_next_record_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_get_record_name_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_create_description_from_record_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_get_field_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_set_field_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_get_object_class_name_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_get_version_cmd( PyObject *self, PyObject *args );


MX_API PyObject *MpPrivate_camac_command_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_camac_get_lam_status_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_camac_controller_command_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_gpib_getline_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_gpib_putline_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_gpib_interface_clear_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_gpib_device_clear_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_gpib_selective_device_clear_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_gpib_local_lockout_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_gpib_remote_enable_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_gpib_go_to_local_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_gpib_trigger_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_gpib_wait_for_service_request_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_gpib_serial_poll_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_gpib_serial_poll_disable_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_modbus_read_coils_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_modbus_read_discrete_inputs_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_modbus_read_holding_registers_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_modbus_read_input_registers_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_modbus_write_single_coil_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_modbus_write_single_register_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_modbus_read_exception_status_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_modbus_get_comm_event_counter_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_modbus_write_multiple_coils_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_modbus_write_multiple_registers_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_modbus_mask_write_register_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_modbus_read_write_multiple_registers_cmd(
							PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_modbus_read_fifo_queue_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_portio_inp8_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_portio_inp16_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_portio_outp8_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_portio_outp16_cmd( PyObject *self, PyObject *args );


MX_API PyObject *MpPrivate_rs232_getchar_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_rs232_putchar_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_rs232_read_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_rs232_write_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_rs232_getline_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_rs232_putline_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_rs232_input_is_available_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_rs232_discard_unread_input_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_rs232_discard_unwritten_output_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_rs232_get_signal_state_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_rs232_set_signal_state_cmd( PyObject *self, 
							PyObject *args );


MX_API PyObject *MpPrivate_usb_enumerate_devices_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_usb_find_device_by_order_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_usb_find_device_by_serial_number_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_usb_delete_device_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_usb_reset_device_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_usb_control_transfer_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_usb_bulk_read_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_usb_bulk_write_cmd( PyObject *self, PyObject *args );


MX_API PyObject *MpPrivate_vme_in8_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_vme_in16_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_vme_in32_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_vme_out8_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_vme_out16_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_vme_out32_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_vme_multi_in8_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_vme_multi_in16_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_vme_multi_in32_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_vme_multi_out8_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_vme_multi_out16_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_vme_multi_out32_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_vme_get_read_address_increment_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_vme_set_read_address_increment_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_vme_get_write_address_increment_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_vme_set_write_address_increment_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_amplifier_get_gain_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_amplifier_set_gain_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_amplifier_get_offset_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_amplifier_set_offset_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_amplifier_get_time_constant_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_amplifier_set_time_constant_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_analog_input_read_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_analog_input_read_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_ainput_read_raw_long_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_ainput_read_raw_double_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_analog_input_get_dark_current_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_analog_input_set_dark_current_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_analog_output_read_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_aoutput_read_raw_long_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_aoutput_read_raw_double_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_analog_output_write_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_aoutput_write_raw_long_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_aoutput_write_raw_double_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_autoscale_read_monitor_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_autoscale_get_change_request_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_autoscale_change_control_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_autoscale_get_offset_index_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_autoscale_set_offset_index_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_autoscale_get_offsets_cmd( PyObject *self,
							PyObject *args );
					
MX_API PyObject *MpPrivate_autoscale_set_offsets_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_autoscale_get_limits_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_autoscale_set_limits_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_autoscale_compute_dynamic_limits_cmd(
					PyObject *self, PyObject *args );


MX_API PyObject *MpPrivate_ccd_start_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ccd_start_for_preset_time_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_ccd_stop_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ccd_get_status_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ccd_readout_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ccd_dezinger_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ccd_correct_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ccd_writefile_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ccd_get_data_frame_size_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_ccd_get_bin_size_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_ccd_set_bin_size_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_ccd_write_header_variable_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_digital_input_read_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_digital_output_read_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_digital_output_write_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_encoder_get_overflow_status_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_encoder_reset_overflow_status_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_encoder_read_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_encoder_write_cmd( PyObject *self, PyObject *args );


MX_API PyObject *MpPrivate_mca_start_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mca_stop_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mca_read_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mca_clear_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mca_is_busy_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mca_start_without_preset_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_start_with_preset_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_start_for_live_time_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_start_for_real_time_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_start_for_preset_count_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_get_parameter_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_set_parameter_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_get_preset_type_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_set_preset_type_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_get_preset_count_region_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_set_preset_count_region_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_get_roi_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mca_set_roi_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mca_get_roi_integral_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_get_rois_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mca_set_rois_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mca_get_roi_integrals_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_get_num_channels_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_set_num_channels_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_get_channel_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_get_real_time_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_get_live_time_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_get_counts_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_get_soft_roi_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_set_soft_roi_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_get_soft_roi_integral_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_mce_get_overflow_status_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mce_reset_overflow_status_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mce_read_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mce_get_current_num_values_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_mcs_start_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mcs_stop_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mcs_clear_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mcs_is_busy_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mcs_read_all_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mcs_read_scaler_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mcs_read_measurement_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mcs_read_timer_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mcs_get_mode_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mcs_set_mode_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mcs_get_measurement_time_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mcs_set_measurement_time_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mcs_get_measurement_counts_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mcs_set_measurement_counts_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mcs_get_num_measurements_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mcs_set_num_measurements_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_motor_is_busy_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_motor_move_absolute_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_motor_move_relative_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_motor_move_absolute_with_flags_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_motor_move_relative_with_flags_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_motor_wait_for_motor_stop_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_motor_get_position_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_motor_set_position_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_motor_soft_abort_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_motor_immediate_abort_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_motor_positive_limit_hit_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_negative_limit_hit_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_find_home_position_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_constant_velocity_move_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_get_speed_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_motor_set_speed_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_motor_get_base_speed_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_motor_set_base_speed_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_motor_get_maximum_speed_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_set_maximum_speed_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_save_speed_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_restore_speed_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_set_speed_between_positions_cmd(
							PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_get_accel_type_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_get_raw_accel_parameters_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_set_raw_accel_parameters_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_get_accel_time_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_set_accel_time_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_get_accel_distance_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_home_search_succeeded_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_get_gain_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_set_gain_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_send_control_command_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_multiple_motors_move_absolute_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_wait_for_multiple_motors_stop_cmd( PyObject *self, 
							PyObject *args );


MX_API PyObject *MpPrivate_pulse_generator_is_busy_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_pulse_generator_start_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_pulse_generator_stop_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_pulse_generator_get_mode_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_pulse_generator_set_mode_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_pulse_generator_get_pulse_period_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_pulse_generator_set_pulse_period_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_pulse_generator_get_pulse_width_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_pulse_generator_set_pulse_width_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_pulse_generator_get_num_pulses_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_pulse_generator_set_num_pulses_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_pulse_generator_get_pulse_delay_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_pulse_generator_set_pulse_delay_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_relay_command_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_relay_get_relay_status_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_sample_changer_initialize_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_shutdown_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_select_sample_holder_cmd(
							PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_unselect_sample_holder_cmd(
							PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_grab_sample_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_ungrab_sample_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_mount_sample_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_unmount_sample_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_get_sample_id_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_set_sample_id_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_soft_abort_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_immediate_abort_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_idle_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_reset_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_get_status_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_is_busy_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_cooldown_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_deice_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_sca_get_lower_level_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sca_set_lower_level_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sca_get_upper_level_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sca_set_upper_level_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sca_get_gain_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_sca_set_gain_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_sca_get_time_constant_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sca_set_time_constant_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sca_get_mode_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_sca_set_mode_cmd( PyObject *self, PyObject *args );


MX_API PyObject *MpPrivate_scaler_clear_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_scaler_overflow_set_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_scaler_read_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_scaler_read_raw_cmd( PyObject *self, PyObject *args);

MX_API PyObject *MpPrivate_scaler_is_busy_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_scaler_start_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_scaler_stop_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_scaler_get_mode_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_scaler_set_mode_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_scaler_set_modes_of_associated_counters_cmd(
							PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_scaler_get_dark_current_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_scaler_set_dark_current_cmd( PyObject *self, 
							PyObject *args );


MX_API PyObject *MpPrivate_table_is_busy_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_table_move_absolute_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_table_get_position_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_table_set_position_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_table_soft_abort_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_table_immediate_abort_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_table_positive_limit_hit_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_table_negative_limit_hit_cmd( PyObject *self, 
							PyObject *args );


MX_API PyObject *MpPrivate_timer_is_busy_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_timer_start_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_timer_stop_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_timer_clear_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_timer_read_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_timer_get_mode_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_timer_set_mode_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_timer_set_modes_of_associated_counters_cmd(
					PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_timer_get_last_measurement_time_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_scan_perform_scan_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_send_variable_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_receive_variable_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_log_open_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_log_close_cmd( PyObject *self, PyObject *args );

#endif /* __MP_H__ */

