/*
 * Name:    mp_main.c
 *
 * Purpose: This file contains the initialization function and method table
 *          for the MpPrivate_private module interface to the MX library.
 *          Python programs should not invoked this module directly but
 *          should invoke the Mp module in 'Mp.py' instead.
 *
 * Author:  William Lavender
 *
 *---------------------------------------------------------------------------
 *
 * Copyright 2002-2004 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#include "Python.h"

#include <signal.h>

#include "mx_util.h"
#include "mx_record.h"
#include "mx_handle.h"
#include "mp.h"

/* Method table for the MpPrivate module. */

static PyMethodDef MpMethods[] = {
	{ "init",
			MpPrivate_init_cmd,
			METH_VARARGS },
	{ "info",
			MpPrivate_info_cmd,
			METH_VARARGS },
	{ "set_info_output_function",
			MpPrivate_set_info_output_function_cmd,
			METH_VARARGS },
	{ "warning",
			MpPrivate_warning_cmd,
			METH_VARARGS },
	{ "set_warning_output_function",
			MpPrivate_set_warning_output_function_cmd,
			METH_VARARGS },
	{ "set_error_output_function",
			MpPrivate_set_error_output_function_cmd,
			METH_VARARGS },
	{ "info_dialog",
			MpPrivate_info_dialog_cmd,
			METH_VARARGS },
	{ "set_info_dialog_function",
			MpPrivate_set_info_dialog_function_cmd,
			METH_VARARGS },
	{ "debug",
			MpPrivate_debug_cmd,
			METH_VARARGS },
	{ "set_debug_output_function",
			MpPrivate_set_debug_output_function_cmd,
			METH_VARARGS },
	{ "get_debug_level",
			MpPrivate_get_debug_level_cmd,
			METH_VARARGS },
	{ "set_debug_level",
			MpPrivate_set_debug_level_cmd,
			METH_VARARGS },
	{ "getch",
			MpPrivate_getch_cmd,
			METH_VARARGS },
	{ "kbhit",
			MpPrivate_kbhit_cmd,
			METH_VARARGS },
	{ "user_requested_interrupt",
			MpPrivate_user_requested_interrupt_cmd,
			METH_VARARGS },
	{ "set_user_interrupt_function",
			MpPrivate_set_user_interrupt_function_cmd,
			METH_VARARGS },
	{ "plotting_is_enabled",
			MpPrivate_plotting_is_enabled_cmd,
			METH_VARARGS },
	{ "set_plot_enable",
			MpPrivate_set_plot_enable_cmd,
			METH_VARARGS },
	{ "set_program_name",
			MpPrivate_set_program_name_cmd,
			METH_VARARGS },
	{ "create_record_list",
			MpPrivate_create_record_list_cmd,
			METH_VARARGS },
	{ "read_database",
			MpPrivate_read_database_cmd,
			METH_VARARGS },
	{ "finish_database_initialization",
			MpPrivate_finish_database_initialization_cmd,
			METH_VARARGS },
	{ "initialize_hardware",
			MpPrivate_initialize_hardware_cmd,
			METH_VARARGS },
	{ "shutdown_hardware",
			MpPrivate_shutdown_hardware_cmd,
			METH_VARARGS },
	{ "create_record_from_description",
			MpPrivate_create_record_from_description_cmd,
			METH_VARARGS },
	{ "finish_record_initialization",
			MpPrivate_finish_record_initialization_cmd,
			METH_VARARGS },
	{ "delete_record",
			MpPrivate_delete_record_cmd,
			METH_VARARGS },
	{ "get_record",
			MpPrivate_get_record_cmd,
			METH_VARARGS },
	{ "get_next_record",
			MpPrivate_get_next_record_cmd,
			METH_VARARGS },
	{ "get_record_name",
			MpPrivate_get_record_name_cmd,
			METH_VARARGS },
	{ "create_description_from_record",
			MpPrivate_create_description_from_record_cmd,
			METH_VARARGS },
	{ "get_field",
			MpPrivate_get_field_cmd,
			METH_VARARGS },
	{ "set_field",
			MpPrivate_set_field_cmd,
			METH_VARARGS },
	{ "get_object_class_name",
			MpPrivate_get_object_class_name_cmd,
			METH_VARARGS },
	{ "get_version",
			MpPrivate_get_version_cmd,
			METH_VARARGS },
	{ "log_open",
			MpPrivate_log_open_cmd,
			METH_VARARGS },
	{ "log_close",
			MpPrivate_log_close_cmd,
			METH_VARARGS },

	{ "camac_command",
			MpPrivate_camac_command_cmd,
			METH_VARARGS },
	{ "camac_get_lam_status",
			MpPrivate_camac_get_lam_status_cmd,
			METH_VARARGS },
	{ "camac_controller_command",
			MpPrivate_camac_controller_command_cmd,
			METH_VARARGS },

	{ "gpib_getline",
			MpPrivate_gpib_getline_cmd,
			METH_VARARGS },
	{ "gpib_putline",
			MpPrivate_gpib_putline_cmd,
			METH_VARARGS },
	{ "gpib_interface_clear",
			MpPrivate_gpib_interface_clear_cmd,
			METH_VARARGS },
	{ "gpib_device_clear",
			MpPrivate_gpib_device_clear_cmd,
			METH_VARARGS },
	{ "gpib_selective_device_clear",
			MpPrivate_gpib_selective_device_clear_cmd,
			METH_VARARGS },
	{ "gpib_local_lockout",
			MpPrivate_gpib_local_lockout_cmd,
			METH_VARARGS },
	{ "gpib_remote_enable",
			MpPrivate_gpib_remote_enable_cmd,
			METH_VARARGS },
	{ "gpib_go_to_local",
			MpPrivate_gpib_go_to_local_cmd,
			METH_VARARGS },
	{ "gpib_trigger",
			MpPrivate_gpib_trigger_cmd,
			METH_VARARGS },
	{ "gpib_wait_for_service_request",
			MpPrivate_gpib_wait_for_service_request_cmd,
			METH_VARARGS },
	{ "gpib_serial_poll",
			MpPrivate_gpib_serial_poll_cmd,
			METH_VARARGS },
	{ "gpib_serial_poll_disable",
			MpPrivate_gpib_serial_poll_disable_cmd,
			METH_VARARGS },

	{ "modbus_read_coils",
			MpPrivate_modbus_read_coils_cmd,
			METH_VARARGS },
	{ "modbus_read_discrete_inputs",
			MpPrivate_modbus_read_discrete_inputs_cmd,
			METH_VARARGS },
	{ "modbus_read_holding_registers",
			MpPrivate_modbus_read_holding_registers_cmd,
			METH_VARARGS },
	{ "modbus_read_input_registers",
			MpPrivate_modbus_read_input_registers_cmd,
			METH_VARARGS },
	{ "modbus_write_single_coil",
			MpPrivate_modbus_write_single_coil_cmd,
			METH_VARARGS },
	{ "modbus_write_single_register",
			MpPrivate_modbus_write_single_register_cmd,
			METH_VARARGS },
	{ "modbus_read_exception_status",
			MpPrivate_modbus_read_exception_status_cmd,
			METH_VARARGS },
	{ "modbus_get_comm_event_counter",
			MpPrivate_modbus_get_comm_event_counter_cmd,
			METH_VARARGS },
	{ "modbus_write_multiple_coils",
			MpPrivate_modbus_write_multiple_coils_cmd,
			METH_VARARGS },
	{ "modbus_write_multiple_registers",
			MpPrivate_modbus_write_multiple_registers_cmd,
			METH_VARARGS },
	{ "modbus_mask_write_register",
			MpPrivate_modbus_mask_write_register_cmd,
			METH_VARARGS },
	{ "modbus_read_write_multiple_registers",
			MpPrivate_modbus_read_write_multiple_registers_cmd,
			METH_VARARGS },
	{ "modbus_read_fifo_queue",
			MpPrivate_modbus_read_fifo_queue_cmd,
			METH_VARARGS },

	{ "portio_inp8",
			MpPrivate_portio_inp8_cmd,
			METH_VARARGS },
	{ "portio_inp16",
			MpPrivate_portio_inp16_cmd,
			METH_VARARGS },
	{ "portio_outp8",
			MpPrivate_portio_outp8_cmd,
			METH_VARARGS },
	{ "portio_outp16",
			MpPrivate_portio_outp16_cmd,
			METH_VARARGS },

	{ "rs232_getchar",
			MpPrivate_rs232_getchar_cmd,
			METH_VARARGS },
	{ "rs232_putchar",
			MpPrivate_rs232_putchar_cmd,
			METH_VARARGS },
	{ "rs232_read",
			MpPrivate_rs232_read_cmd,
			METH_VARARGS },
	{ "rs232_write",
			MpPrivate_rs232_write_cmd,
			METH_VARARGS },
	{ "rs232_getline",
			MpPrivate_rs232_getline_cmd,
			METH_VARARGS },
	{ "rs232_putline",
			MpPrivate_rs232_putline_cmd,
			METH_VARARGS },
	{ "rs232_input_is_available",
			MpPrivate_rs232_input_is_available_cmd,
			METH_VARARGS },
	{ "rs232_discard_unread_input",
			MpPrivate_rs232_discard_unread_input_cmd,
			METH_VARARGS },
	{ "rs232_discard_unwritten_output",
			MpPrivate_rs232_discard_unwritten_output_cmd,
			METH_VARARGS },
	{ "rs232_get_signal_state",
			MpPrivate_rs232_get_signal_state_cmd,
			METH_VARARGS },
	{ "rs232_set_signal_state",
			MpPrivate_rs232_set_signal_state_cmd,
			METH_VARARGS },

	{ "usb_enumerate_devices",
			MpPrivate_usb_enumerate_devices_cmd,
			METH_VARARGS },
	{ "usb_find_device_by_order",
			MpPrivate_usb_find_device_by_order_cmd,
			METH_VARARGS },
	{ "usb_find_device_by_serial_number",
			MpPrivate_usb_find_device_by_serial_number_cmd,
			METH_VARARGS },
	{ "usb_delete_device",
			MpPrivate_usb_delete_device_cmd,
			METH_VARARGS },
	{ "usb_reset_device",
			MpPrivate_usb_reset_device_cmd,
			METH_VARARGS },
	{ "usb_control_transfer",
			MpPrivate_usb_control_transfer_cmd,
			METH_VARARGS },
	{ "usb_bulk_read",
			MpPrivate_usb_bulk_read_cmd,
			METH_VARARGS },
	{ "usb_bulk_write",
			MpPrivate_usb_bulk_write_cmd,
			METH_VARARGS },

	{ "vme_in8",
			MpPrivate_vme_in8_cmd,
			METH_VARARGS },
	{ "vme_in16",
			MpPrivate_vme_in16_cmd,
			METH_VARARGS },
	{ "vme_in32",
			MpPrivate_vme_in32_cmd,
			METH_VARARGS },
	{ "vme_out8",
			MpPrivate_vme_out8_cmd,
			METH_VARARGS },
	{ "vme_out16",
			MpPrivate_vme_out16_cmd,
			METH_VARARGS },
	{ "vme_out32",
			MpPrivate_vme_out32_cmd,
			METH_VARARGS },
	{ "vme_multi_in8",
			MpPrivate_vme_multi_in8_cmd,
			METH_VARARGS },
	{ "vme_multi_in16",
			MpPrivate_vme_multi_in16_cmd,
			METH_VARARGS },
	{ "vme_multi_in32",
			MpPrivate_vme_multi_in32_cmd,
			METH_VARARGS },
	{ "vme_multi_out8",
			MpPrivate_vme_multi_out8_cmd,
			METH_VARARGS },
	{ "vme_multi_out16",
			MpPrivate_vme_multi_out16_cmd,
			METH_VARARGS },
	{ "vme_multi_out32",
			MpPrivate_vme_multi_out32_cmd,
			METH_VARARGS },
	{ "vme_multi_get_read_address_increment",
			MpPrivate_vme_get_read_address_increment_cmd,
			METH_VARARGS },
	{ "vme_multi_set_read_address_increment",
			MpPrivate_vme_set_read_address_increment_cmd,
			METH_VARARGS },
	{ "vme_multi_get_write_address_increment",
			MpPrivate_vme_get_write_address_increment_cmd,
			METH_VARARGS },
	{ "vme_multi_set_write_address_increment",
			MpPrivate_vme_set_write_address_increment_cmd,
			METH_VARARGS },

	{ "amplifier_get_gain",
			MpPrivate_amplifier_get_gain_cmd,
			METH_VARARGS },
	{ "amplifier_set_gain",
			MpPrivate_amplifier_set_gain_cmd,
			METH_VARARGS },
	{ "amplifier_get_offset",
			MpPrivate_amplifier_get_offset_cmd,
			METH_VARARGS },
	{ "amplifier_set_offset",
			MpPrivate_amplifier_set_offset_cmd,
			METH_VARARGS },
	{ "amplifier_get_time_constant",
			MpPrivate_amplifier_get_time_constant_cmd,
			METH_VARARGS },
	{ "amplifier_set_time_constant",
			MpPrivate_amplifier_set_time_constant_cmd,
			METH_VARARGS },

	{ "analog_input_read",
			MpPrivate_analog_input_read_cmd,
			METH_VARARGS },
	{ "analog_input_read_raw_long",
			MpPrivate_ainput_read_raw_long_cmd,
			METH_VARARGS },
	{ "analog_input_read_raw_double",
			MpPrivate_ainput_read_raw_double_cmd,
			METH_VARARGS },
	{ "analog_input_get_dark_current",
			MpPrivate_analog_input_get_dark_current_cmd,
			METH_VARARGS },
	{ "analog_input_set_dark_current",
			MpPrivate_analog_input_set_dark_current_cmd,
			METH_VARARGS },

	{ "analog_output_read",
			MpPrivate_analog_output_read_cmd,
			METH_VARARGS },
	{ "analog_output_read_raw_long",
			MpPrivate_aoutput_read_raw_long_cmd,
			METH_VARARGS },
	{ "analog_output_read_raw_double",
			MpPrivate_aoutput_read_raw_double_cmd,
			METH_VARARGS },
	{ "analog_output_write",
			MpPrivate_analog_output_write_cmd,
			METH_VARARGS },
	{ "analog_output_write_raw_long",
			MpPrivate_aoutput_write_raw_long_cmd,
			METH_VARARGS },
	{ "analog_output_write_raw_double",
			MpPrivate_aoutput_write_raw_double_cmd,
			METH_VARARGS },

	{ "ccd_start",
			MpPrivate_ccd_start_cmd,
			METH_VARARGS },
	{ "ccd_start_for_preset_time",
			MpPrivate_ccd_start_for_preset_time_cmd,
			METH_VARARGS },
	{ "ccd_stop",
			MpPrivate_ccd_stop_cmd,
			METH_VARARGS },
	{ "ccd_get_status",
			MpPrivate_ccd_get_status_cmd,
			METH_VARARGS },
	{ "ccd_readout",
			MpPrivate_ccd_readout_cmd,
			METH_VARARGS },
	{ "ccd_dezinger",
			MpPrivate_ccd_dezinger_cmd,
			METH_VARARGS },
	{ "ccd_correct",
			MpPrivate_ccd_correct_cmd,
			METH_VARARGS },
	{ "ccd_writefile",
			MpPrivate_ccd_writefile_cmd,
			METH_VARARGS },
	{ "ccd_get_data_frame_size",
			MpPrivate_ccd_get_data_frame_size_cmd,
			METH_VARARGS },
	{ "ccd_get_bin_size",
			MpPrivate_ccd_get_bin_size_cmd,
			METH_VARARGS },
	{ "ccd_set_bin_size",
			MpPrivate_ccd_set_bin_size_cmd,
			METH_VARARGS },
	{ "ccd_write_header_variable",
			MpPrivate_ccd_write_header_variable_cmd,
			METH_VARARGS },

	{ "digital_input_read",
			MpPrivate_digital_input_read_cmd,
			METH_VARARGS },

	{ "digital_output_read",
			MpPrivate_digital_output_read_cmd,
			METH_VARARGS },
	{ "digital_output_write",
			MpPrivate_digital_output_write_cmd,
			METH_VARARGS },

	{ "mca_start",
			MpPrivate_mca_start_cmd,
			METH_VARARGS },
	{ "mca_stop",
			MpPrivate_mca_stop_cmd,
			METH_VARARGS },
	{ "mca_read",
			MpPrivate_mca_read_cmd,
			METH_VARARGS },
	{ "mca_clear",
			MpPrivate_mca_clear_cmd,
			METH_VARARGS },
	{ "mca_is_busy",
			MpPrivate_mca_is_busy_cmd,
			METH_VARARGS },
	{ "mca_start_without_preset",
			MpPrivate_mca_start_without_preset_cmd,
			METH_VARARGS },
	{ "mca_start_for_preset_live_time",
			MpPrivate_mca_start_for_live_time_cmd,
			METH_VARARGS },
	{ "mca_start_for_preset_real_time",
			MpPrivate_mca_start_for_real_time_cmd,
			METH_VARARGS },
	{ "mca_start_for_preset_count",
			MpPrivate_mca_start_for_preset_count_cmd,
			METH_VARARGS },
	{ "mca_get_preset_type",
			MpPrivate_mca_get_preset_type_cmd,
			METH_VARARGS },
	{ "mca_set_preset_type",
			MpPrivate_mca_set_preset_type_cmd,
			METH_VARARGS },
	{ "mca_get_preset_count_region",
			MpPrivate_mca_get_preset_count_region_cmd,
			METH_VARARGS },
	{ "mca_set_preset_count_region",
			MpPrivate_mca_set_preset_count_region_cmd,
			METH_VARARGS },
	{ "mca_get_roi",
			MpPrivate_mca_get_roi_cmd,
			METH_VARARGS },
	{ "mca_set_roi",
			MpPrivate_mca_set_roi_cmd,
			METH_VARARGS },
	{ "mca_get_roi_integral",
			MpPrivate_mca_get_roi_integral_cmd,
			METH_VARARGS },
	{ "mca_get_rois",
			MpPrivate_mca_get_rois_cmd,
			METH_VARARGS },
	{ "mca_set_rois",
			MpPrivate_mca_set_rois_cmd,
			METH_VARARGS },
	{ "mca_get_roi_integrals",
			MpPrivate_mca_get_roi_integrals_cmd,
			METH_VARARGS },
	{ "mca_get_num_channels",
			MpPrivate_mca_get_num_channels_cmd,
			METH_VARARGS },
	{ "mca_set_num_channels",
			MpPrivate_mca_set_num_channels_cmd,
			METH_VARARGS },
	{ "mca_get_channel",
			MpPrivate_mca_get_channel_cmd,
			METH_VARARGS },
	{ "mca_get_real_time",
			MpPrivate_mca_get_real_time_cmd,
			METH_VARARGS },
	{ "mca_get_live_time",
			MpPrivate_mca_get_live_time_cmd,
			METH_VARARGS },
	{ "mca_get_counts",
			MpPrivate_mca_get_counts_cmd,
			METH_VARARGS },
	{ "mca_get_soft_roi",
			MpPrivate_mca_get_soft_roi_cmd,
			METH_VARARGS },
	{ "mca_set_soft_roi",
			MpPrivate_mca_set_soft_roi_cmd,
			METH_VARARGS },
	{ "mca_get_soft_roi_integral",
			MpPrivate_mca_get_soft_roi_integral_cmd,
			METH_VARARGS },

	{ "mcs_start",
			MpPrivate_mcs_start_cmd,
			METH_VARARGS },
	{ "mcs_stop",
			MpPrivate_mcs_stop_cmd,
			METH_VARARGS },
	{ "mcs_clear",
			MpPrivate_mcs_clear_cmd,
			METH_VARARGS },
	{ "mcs_is_busy",
			MpPrivate_mcs_is_busy_cmd,
			METH_VARARGS },
	{ "mcs_read_all",
			MpPrivate_mcs_read_all_cmd,
			METH_VARARGS },
	{ "mcs_read_scaler",
			MpPrivate_mcs_read_scaler_cmd,
			METH_VARARGS },
	{ "mcs_read_measurement",
			MpPrivate_mcs_read_measurement_cmd,
			METH_VARARGS },
	{ "mcs_read_timer",
			MpPrivate_mcs_read_timer_cmd,
			METH_VARARGS },
	{ "mcs_get_mode",
			MpPrivate_mcs_get_mode_cmd,
			METH_VARARGS },
	{ "mcs_set_mode",
			MpPrivate_mcs_set_mode_cmd,
			METH_VARARGS },
	{ "mcs_get_measurement_time",
			MpPrivate_mcs_get_measurement_time_cmd,
			METH_VARARGS },
	{ "mcs_set_measurement_time",
			MpPrivate_mcs_set_measurement_time_cmd,
			METH_VARARGS },
	{ "mcs_get_measurement_counts",
			MpPrivate_mcs_get_measurement_counts_cmd,
			METH_VARARGS },
	{ "mcs_set_measurement_counts",
			MpPrivate_mcs_set_measurement_counts_cmd,
			METH_VARARGS },
	{ "mcs_get_num_measurements",
			MpPrivate_mcs_get_num_measurements_cmd,
			METH_VARARGS },
	{ "mcs_set_num_measurements",
			MpPrivate_mcs_set_num_measurements_cmd,
			METH_VARARGS },

	{ "motor_is_busy",
			MpPrivate_motor_is_busy_cmd,
			METH_VARARGS },
	{ "motor_move_absolute",
			MpPrivate_motor_move_absolute_cmd,
			METH_VARARGS },
	{ "motor_move_relative",
			MpPrivate_motor_move_relative_cmd,
			METH_VARARGS },
	{ "motor_move_absolute_with_flags",
			MpPrivate_motor_move_absolute_with_flags_cmd,
			METH_VARARGS },
	{ "motor_move_relative_with_flags",
			MpPrivate_motor_move_relative_with_flags_cmd,
			METH_VARARGS },
	{ "motor_wait_for_motor_stop",
			MpPrivate_motor_wait_for_motor_stop_cmd,
			METH_VARARGS },
	{ "motor_get_position",
			MpPrivate_motor_get_position_cmd,
			METH_VARARGS },
	{ "motor_set_position",
			MpPrivate_motor_set_position_cmd,
			METH_VARARGS },
	{ "motor_soft_abort",
			MpPrivate_motor_soft_abort_cmd,
			METH_VARARGS },
	{ "motor_immediate_abort",
			MpPrivate_motor_immediate_abort_cmd,
			METH_VARARGS },
	{ "motor_positive_limit_hit",
			MpPrivate_motor_positive_limit_hit_cmd,
			METH_VARARGS },
	{ "motor_negative_limit_hit",
			MpPrivate_motor_negative_limit_hit_cmd,
			METH_VARARGS },
	{ "motor_find_home_position",
			MpPrivate_motor_find_home_position_cmd,
			METH_VARARGS },
	{ "motor_constant_velocity_move",
			MpPrivate_motor_constant_velocity_move_cmd,
			METH_VARARGS },
	{ "motor_get_speed",MpPrivate_motor_get_speed_cmd,
			METH_VARARGS },
	{ "motor_set_speed",
			MpPrivate_motor_set_speed_cmd,
			METH_VARARGS },
	{ "motor_get_base_speed",
			MpPrivate_motor_get_base_speed_cmd,
			METH_VARARGS },
	{ "motor_set_base_speed",
			MpPrivate_motor_set_base_speed_cmd,
			METH_VARARGS },
	{ "motor_get_maximum_speed",
			MpPrivate_motor_get_maximum_speed_cmd,
			METH_VARARGS },
	{ "motor_set_maximum_speed",
			MpPrivate_motor_set_maximum_speed_cmd,
			METH_VARARGS },
	{ "motor_save_speed",
			MpPrivate_motor_save_speed_cmd,
			METH_VARARGS },
	{ "motor_restore_speed",
			MpPrivate_motor_restore_speed_cmd,
			METH_VARARGS },
	{ "motor_set_speed_between_positions",
			MpPrivate_motor_set_speed_between_positions_cmd,
			METH_VARARGS },
	{ "motor_get_acceleration_type",
			MpPrivate_motor_get_accel_type_cmd,
			METH_VARARGS },
	{ "motor_get_raw_acceleration_parameters",
			MpPrivate_motor_get_raw_accel_parameters_cmd,
			METH_VARARGS },
	{ "motor_set_raw_acceleration_parameters",
			MpPrivate_motor_set_raw_accel_parameters_cmd,
			METH_VARARGS },
	{ "motor_get_acceleration_time",
			MpPrivate_motor_get_accel_time_cmd,
			METH_VARARGS },
	{ "motor_set_acceleration_time",
			MpPrivate_motor_set_accel_time_cmd,
			METH_VARARGS },
	{ "motor_get_acceleration_distance",
			MpPrivate_motor_get_accel_distance_cmd,
			METH_VARARGS },
	{ "motor_home_search_succeeded",
			MpPrivate_motor_home_search_succeeded_cmd,
			METH_VARARGS },
	{ "motor_get_gain",
			MpPrivate_motor_get_gain_cmd,
			METH_VARARGS },
	{ "motor_set_gain",
			MpPrivate_motor_set_gain_cmd,
			METH_VARARGS },
	{ "motor_send_control_command",
			MpPrivate_motor_send_control_command_cmd,
			METH_VARARGS },

	{ "multiple_motors_move_absolute",
			MpPrivate_multiple_motors_move_absolute_cmd,
			METH_VARARGS },
	{ "wait_for_multiple_motors_stop",
			MpPrivate_wait_for_multiple_motors_stop_cmd,
			METH_VARARGS },

	{ "pulse_generator_is_busy",
			MpPrivate_pulse_generator_is_busy_cmd,
			METH_VARARGS },
	{ "pulse_generator_start",
			MpPrivate_pulse_generator_start_cmd,
			METH_VARARGS },
	{ "pulse_generator_stop",
			MpPrivate_pulse_generator_stop_cmd,
			METH_VARARGS },
	{ "pulse_generator_get_mode",
			MpPrivate_pulse_generator_get_mode_cmd,
			METH_VARARGS },
	{ "pulse_generator_set_mode",
			MpPrivate_pulse_generator_set_mode_cmd,
			METH_VARARGS },
	{ "pulse_generator_get_pulse_period",
			MpPrivate_pulse_generator_get_pulse_period_cmd,
			METH_VARARGS },
	{ "pulse_generator_set_pulse_period",
			MpPrivate_pulse_generator_set_pulse_period_cmd,
			METH_VARARGS },
	{ "pulse_generator_get_pulse_width",
			MpPrivate_pulse_generator_get_pulse_width_cmd,
			METH_VARARGS },
	{ "pulse_generator_set_pulse_width",
			MpPrivate_pulse_generator_set_pulse_width_cmd,
			METH_VARARGS },
	{ "pulse_generator_get_num_pulses",
			MpPrivate_pulse_generator_get_num_pulses_cmd,
			METH_VARARGS },
	{ "pulse_generator_set_num_pulses",
			MpPrivate_pulse_generator_set_num_pulses_cmd,
			METH_VARARGS },
	{ "pulse_generator_get_pulse_delay",
			MpPrivate_pulse_generator_get_pulse_delay_cmd,
			METH_VARARGS },
	{ "pulse_generator_set_pulse_delay",
			MpPrivate_pulse_generator_set_pulse_delay_cmd,
			METH_VARARGS },

	{ "relay_command",
			MpPrivate_relay_command_cmd,
			METH_VARARGS },
	{ "get_relay_status",
			MpPrivate_relay_get_relay_status_cmd,
			METH_VARARGS },

	{ "sample_changer_initialize",
			MpPrivate_sample_changer_initialize_cmd,
			METH_VARARGS },
	{ "sample_changer_shutdown",
			MpPrivate_sample_changer_shutdown_cmd,
			METH_VARARGS },
	{ "sample_changer_select_sample_holder",
			MpPrivate_sample_changer_select_sample_holder_cmd,
			METH_VARARGS },
	{ "sample_changer_unselect_sample_holder",
			MpPrivate_sample_changer_unselect_sample_holder_cmd,
			METH_VARARGS },
	{ "sample_changer_grab_sample",
			MpPrivate_sample_changer_grab_sample_cmd,
			METH_VARARGS },
	{ "sample_changer_ungrab_sample",
			MpPrivate_sample_changer_ungrab_sample_cmd,
			METH_VARARGS },
	{ "sample_changer_mount_sample",
			MpPrivate_sample_changer_mount_sample_cmd,
			METH_VARARGS },
	{ "sample_changer_unmount_sample",
			MpPrivate_sample_changer_unmount_sample_cmd,
			METH_VARARGS },
	{ "sample_changer_get_sample_id",
			MpPrivate_sample_changer_get_sample_id_cmd,
			METH_VARARGS },
	{ "sample_changer_set_sample_id",
			MpPrivate_sample_changer_set_sample_id_cmd,
			METH_VARARGS },
	{ "sample_changer_soft_abort",
			MpPrivate_sample_changer_soft_abort_cmd,
			METH_VARARGS },
	{ "sample_changer_immediate_abort",
			MpPrivate_sample_changer_immediate_abort_cmd,
			METH_VARARGS },
	{ "sample_changer_idle",
			MpPrivate_sample_changer_idle_cmd,
			METH_VARARGS },
	{ "sample_changer_reset",
			MpPrivate_sample_changer_reset_cmd,
			METH_VARARGS },
	{ "sample_changer_get_status",
			MpPrivate_sample_changer_get_status_cmd,
			METH_VARARGS },
	{ "sample_changer_is_busy",
			MpPrivate_sample_changer_is_busy_cmd,
			METH_VARARGS },
	{ "sample_changer_cooldown",
			MpPrivate_sample_changer_cooldown_cmd,
			METH_VARARGS },
	{ "sample_changer_deice",
			MpPrivate_sample_changer_deice_cmd,
			METH_VARARGS },

	{ "sca_get_lower_level",
			MpPrivate_sca_get_lower_level_cmd,
			METH_VARARGS },
	{ "sca_set_lower_level",
			MpPrivate_sca_set_lower_level_cmd,
			METH_VARARGS },
	{ "sca_get_upper_level",
			MpPrivate_sca_get_upper_level_cmd,
			METH_VARARGS },
	{ "sca_set_upper_level",
			MpPrivate_sca_set_upper_level_cmd,
			METH_VARARGS },
	{ "sca_get_gain",
			MpPrivate_sca_get_gain_cmd,
			METH_VARARGS },
	{ "sca_set_gain",
			MpPrivate_sca_set_gain_cmd,
			METH_VARARGS },
	{ "sca_get_time_constant",
			MpPrivate_sca_get_time_constant_cmd,
			METH_VARARGS },
	{ "sca_set_time_constant",
			MpPrivate_sca_set_time_constant_cmd,
			METH_VARARGS },
	{ "sca_get_mode",
			MpPrivate_sca_get_mode_cmd,
			METH_VARARGS },
	{ "sca_set_mode",
			MpPrivate_sca_set_mode_cmd,
			METH_VARARGS },

	{ "scaler_clear",
			MpPrivate_scaler_clear_cmd,
			METH_VARARGS },
	{ "scaler_overflow_set",
			MpPrivate_scaler_overflow_set_cmd,
			METH_VARARGS },
	{ "scaler_read",
			MpPrivate_scaler_read_cmd,
			METH_VARARGS },
	{ "scaler_read_raw",
			MpPrivate_scaler_read_raw_cmd,
			METH_VARARGS },
	{ "scaler_is_busy",
			MpPrivate_scaler_is_busy_cmd,
			METH_VARARGS },
	{ "scaler_start",
			MpPrivate_scaler_start_cmd,
			METH_VARARGS },
	{ "scaler_stop",
			MpPrivate_scaler_stop_cmd,
			METH_VARARGS },
	{ "scaler_get_mode",
			MpPrivate_scaler_get_mode_cmd,
			METH_VARARGS },
	{ "scaler_set_mode",
			MpPrivate_scaler_set_mode_cmd,
			METH_VARARGS },
	{ "scaler_set_modes_of_associated_counters",
			MpPrivate_scaler_set_modes_of_associated_counters_cmd,
			METH_VARARGS },
	{ "scaler_get_dark_current",
			MpPrivate_scaler_get_dark_current_cmd,
			METH_VARARGS },
	{ "scaler_set_dark_current",
			MpPrivate_scaler_set_dark_current_cmd,
			METH_VARARGS },

	{ "table_is_busy",
			MpPrivate_table_is_busy_cmd,
			METH_VARARGS },
	{ "table_move_absolute",
			MpPrivate_table_move_absolute_cmd,
			METH_VARARGS },
	{ "table_get_position",
			MpPrivate_table_get_position_cmd,
			METH_VARARGS },
	{ "table_set_position",
			MpPrivate_table_set_position_cmd,
			METH_VARARGS },
	{ "table_soft_abort",
			MpPrivate_table_soft_abort_cmd,
			METH_VARARGS },
	{ "table_immediate_abort",
			MpPrivate_table_immediate_abort_cmd,
			METH_VARARGS },
	{ "table_positive_limit_hit",
			MpPrivate_table_positive_limit_hit_cmd,
			METH_VARARGS },
	{ "table_negative_limit_hit",
			MpPrivate_table_negative_limit_hit_cmd,
			METH_VARARGS },

	{ "timer_is_busy",
			MpPrivate_timer_is_busy_cmd,
			METH_VARARGS },
	{ "timer_start",
			MpPrivate_timer_start_cmd,
			METH_VARARGS },
	{ "timer_stop",
			MpPrivate_timer_stop_cmd,
			METH_VARARGS },
	{ "timer_clear",
			MpPrivate_timer_clear_cmd,
			METH_VARARGS },
	{ "timer_read",
			MpPrivate_timer_read_cmd,
			METH_VARARGS },
	{ "timer_get_mode",
			MpPrivate_timer_get_mode_cmd,
			METH_VARARGS },
	{ "timer_set_mode",
			MpPrivate_timer_set_mode_cmd,
			METH_VARARGS },
	{ "timer_set_modes_of_associated_counters",
			MpPrivate_timer_set_modes_of_associated_counters_cmd,
			METH_VARARGS },
	{ "timer_get_last_measurement_time",
			MpPrivate_timer_get_last_measurement_time_cmd,
			METH_VARARGS },

	{ "scan_perform_scan",
			MpPrivate_scan_perform_scan_cmd,
			METH_VARARGS },

	{ "variable_send_variable",
			MpPrivate_send_variable_cmd,
			METH_VARARGS },
	{ "variable_receive_variable",
			MpPrivate_receive_variable_cmd,
			METH_VARARGS },

	{ NULL, NULL }
};

/* This is MpPrivate's module initialization function. */

MX_EXPORT void
initMpPrivate( void )
{
#if 1
	/* Attempt to print a stack trace when a segmentation fault occurs. */

	signal( SIGSEGV, mx_standard_signal_error_handler );
#endif

	(void) Py_InitModule("MpPrivate", MpMethods);
}

/* The following is the one global variable in libMp. */

MX_HANDLE_TABLE *MpPrivate_global_record_handle_table;

